@@ -77,6 +77,11 @@ var LuaFormat = &Format{"lua", []string{"l"},
 	func() Decoder { return NewLuaDecoder(ConfiguredLuaPreferences) },
 }
 
+var INIFormat = &Format{"ini", []string{"i"},
+	func() Encoder { return NewINIEncoder() },
+	func() Decoder { return NewINIDecoder() },
+}
+
 var Formats = []*Format{
 	YamlFormat,
 	JSONFormat,
@@ -90,6 +95,7 @@ var Formats = []*Format{
 	TomlFormat,
 	ShellVariablesFormat,
 	LuaFormat,
+	INIFormat,
 }
 
 func (f *Format) MatchesName(name string) bool {
@@ -107,7 +113,7 @@ func FormatStringFromFilename(filename string) string {
 	if filename != "" {
 		GetLogger().Debugf("checking filename '%s' for auto format detection", filename)
 		ext := filepath.Ext(filename)
-		if ext != "" && ext[0] == '.' {
+		if len(ext) >= 2 && ext[0] == '.' {
 			format := strings.ToLower(ext[1:])
 			GetLogger().Debugf("detected format '%s'", format)
 			return format
