@@ -28,6 +28,17 @@ func GetLogger() *logging.Logger {
 	return log
 }
 
+func getContentValueByKey(content []*CandidateNode, key string) *CandidateNode {
+	for index := 0; index < len(content); index = index + 2 {
+		keyNode := content[index]
+		valueNode := content[index+1]
+		if keyNode.Value == key {
+			return valueNode
+		}
+	}
+	return nil
+}
+
 func recurseNodeArrayEqual(lhs *CandidateNode, rhs *CandidateNode) bool {
 	if len(lhs.Content) != len(rhs.Content) {
 		return false
@@ -95,10 +106,20 @@ func parseSnippet(value string) (*CandidateNode, error) {
 	if err != nil {
 		return nil, err
 	}
+
+	if result.Kind == ScalarNode {
+		result.LineComment = result.LeadingContent
+	} else {
+		result.HeadComment = result.LeadingContent
+	}
+	result.LeadingContent = ""
+
 	if result.Tag == "!!str" {
 		// use the original string value, as
 		// decoding drops new lines
-		return createScalarNode(value, value), nil
+		newNode := createScalarNode(value, value)
+		newNode.LineComment = result.LineComment
+		return newNode, nil
 	}
 	result.Line = 0
 	result.Column = 0
