@@ -11,6 +11,16 @@ var reverseOperatorScenarios = []expressionScenario{
 			"D0, P[], (!!seq)::[3, 2, 1]\n",
 		},
 	},
+	{
+		description: "Reverse",
+		skipDoc:     true,
+		document:    "[1, 2]",
+		expression:  `reverse[]`,
+		expected: []string{
+			"D0, P[0], (!!int)::2\n",
+			"D0, P[1], (!!int)::1\n",
+		},
+	},
 	{
 		skipDoc:    true,
 		document:   "[]",
