@@ -5,6 +5,12 @@ import (
 )
 
 var selectOperatorScenarios = []expressionScenario{
+	{
+		skipDoc:    true,
+		document:   `cat: pants`,
+		expression: `select(.nope) | key + " why though?"`,
+		expected:   []string{},
+	},
 	{
 		skipDoc:    true,
 		document:   `cat`,
@@ -75,6 +81,17 @@ var selectOperatorScenarios = []expressionScenario{
 			"D0, P[], (!!map)::b: world\n",
 		},
 	},
+	{
+		description: "select splat",
+		skipDoc:     true,
+		document:    "a: hello",
+		document2:   "b: world",
+		expression:  `select(.a == "hello" or .b == "world")[]`,
+		expected: []string{
+			"D0, P[a], (!!str)::hello\n",
+			"D0, P[b], (!!str)::world\n",
+		},
+	},
 	{
 		description: "select does not update the map",
 		skipDoc:     true,
