@@ -6,7 +6,7 @@ import (
 	"math/rand"
 )
 
-func shuffleOperator(d *dataTreeNavigator, context Context, expressionNode *ExpressionNode) (Context, error) {
+func shuffleOperator(_ *dataTreeNavigator, context Context, _ *ExpressionNode) (Context, error) {
 
 	// ignore CWE-338 gosec issue of not using crypto/rand
 	// this is just to shuffle an array rather generating a
@@ -26,7 +26,12 @@ func shuffleOperator(d *dataTreeNavigator, context Context, expressionNode *Expr
 
 		a := result.Content
 
-		myRand.Shuffle(len(a), func(i, j int) { a[i], a[j] = a[j], a[i] })
+		myRand.Shuffle(len(a), func(i, j int) {
+			a[i], a[j] = a[j], a[i]
+			oldIndex := a[i].Key.Value
+			a[i].Key.Value = a[j].Key.Value
+			a[j].Key.Value = oldIndex
+		})
 
 		results.PushBack(result)
 	}
