@@ -6,6 +6,7 @@ import (
 	"container/list"
 	"fmt"
 	"io"
+	"io/fs"
 	"os"
 	"sort"
 	"strings"
@@ -29,12 +30,27 @@ type expressionScenario struct {
 	expectedError         string
 	dontFormatInputForDoc bool // dont format input doc for documentation generation
 	requiresFormat        string
+	skipForGoccy          bool
 }
 
+var goccyTesting = false
+
+var testingDecoder = NewYamlDecoder(ConfiguredYamlPreferences)
+
 func TestMain(m *testing.M) {
-	logging.SetLevel(logging.ERROR, "")
+	logging.SetLevel(logging.WARNING, "")
+	if os.Getenv("DEBUG") == "true" {
+		logging.SetLevel(logging.DEBUG, "")
+	}
 	ConfiguredYamlPreferences.ColorsEnabled = false
 	ConfiguredJSONPreferences.ColorsEnabled = false
+
+	goccyTesting = os.Getenv("GOCCY") == "true"
+
+	if goccyTesting {
+		testingDecoder = NewGoccyYAMLDecoder()
+	}
+
 	Now = func() time.Time {
 		return time.Date(2021, time.May, 19, 1, 2, 3, 4, time.UTC)
 	}
@@ -53,10 +69,14 @@ func NewSimpleYamlPrinter(writer io.Writer, unwrapScalar bool, indent int, print
 func readDocument(content string, fakefilename string, fakeFileIndex int) (*list.List, error) {
 	reader := bufio.NewReader(strings.NewReader(content))
 
-	return readDocuments(reader, fakefilename, fakeFileIndex, NewYamlDecoder(ConfiguredYamlPreferences))
+	return readDocuments(reader, fakefilename, fakeFileIndex, testingDecoder)
 }
 
 func testScenario(t *testing.T, s *expressionScenario) {
+	if s.skipForGoccy {
+		return
+	}
+	log.Debugf("\n\ntesting scenario %v", s.description)
 	var err error
 	node, err := getExpressionParser().ParseExpression(s.expression)
 	if err != nil {
@@ -192,7 +212,7 @@ func formatYaml(yaml string, filename string) string {
 		panic(err)
 	}
 	streamEvaluator := NewStreamEvaluator()
-	_, err = streamEvaluator.Evaluate(filename, strings.NewReader(yaml), node, printer, NewYamlDecoder(ConfiguredYamlPreferences))
+	_, err = streamEvaluator.Evaluate(filename, strings.NewReader(yaml), node, printer, testingDecoder)
 	if err != nil {
 		panic(err)
 	}
@@ -202,7 +222,8 @@ func formatYaml(yaml string, filename string) string {
 type documentScenarioFunc func(t *testing.T, writer *bufio.Writer, scenario interface{})
 
 func documentScenarios(t *testing.T, folder string, title string, scenarios []interface{}, documentScenario documentScenarioFunc) {
-	f, err := os.Create(fmt.Sprintf("doc/%v/%v.md", folder, title))
+	filename := fmt.Sprintf("doc/%v/%v.md", folder, title)
+	f, err := os.Create(filename)
 
 	if err != nil {
 		t.Error(err)
@@ -232,6 +253,22 @@ func documentScenarios(t *testing.T, folder string, title string, scenarios []in
 	w.Flush()
 }
 
+func appendOperatorDocumentScenario(t *testing.T, title string, scenarios []expressionScenario) {
+	filename := fmt.Sprintf("doc/%v/%v.md", "operators", title)
+	f, err := os.OpenFile(filename, os.O_CREATE|os.O_RDWR|os.O_APPEND, fs.ModeAppend)
+	if err != nil {
+		t.Error(err)
+		return
+	}
+	defer f.Close()
+	w := bufio.NewWriter(f)
+	for _, s := range scenarios {
+		documentOperatorScenario(t, w, s)
+	}
+	w.Flush()
+
+}
+
 func documentOperatorScenarios(t *testing.T, title string, scenarios []expressionScenario) {
 	genericScenarios := make([]interface{}, len(scenarios))
 	for i, s := range scenarios {
@@ -348,13 +385,13 @@ func documentOutput(t *testing.T, w *bufio.Writer, s expressionScenario, formatt
 
 		inputs, err = readDocument(formattedDoc, "sample.yml", 0)
 		if err != nil {
-			t.Error(err, s.document, s.expression)
+			t.Error(err, formattedDoc, "exp: "+s.expression)
 			return
 		}
 		if s.document2 != "" {
 			moreInputs, err := readDocument(formattedDoc2, "another.yml", 1)
 			if err != nil {
-				t.Error(err, s.document, s.expression)
+				t.Error(err, formattedDoc2, "exp: "+s.expression)
 				return
 			}
 			inputs.PushBackList(moreInputs)
